###################################################
### chunk number 1: 
###################################################
library(SamplerCompare)
gauss.cor7 <- make.gaussian(mean=c(1,2), rho=0.7)
gamma.shape23 <- make.mv.gamma.dist(shape=c(2,3))
sim.results <- compare.samplers(sample.size=1000,
                                dists=list(gauss.cor7, gamma.shape23),
                                samplers=list(adaptive.metropolis.sample,
                                              arms.sample),
                                tuning=c(1,20,400))


###################################################
### chunk number 2: 
###################################################
print(comparison.plot(sim.results))


###################################################
### chunk number 3: 
###################################################
metropolis.sample <- function(target.dist, x0, sample.size, tuning) {
  X <- matrix(nrow=sample.size, ncol=target.dist$ndim)
  state <- x0
  evals <- 1
  state.log.dens <- target.dist$log.density(state)
  for (obs in 1:sample.size) {
    proposal <- rnorm(target.dist$ndim, state, tuning)
    evals <- evals + 1
    proposal.log.dens <- target.dist$log.density(proposal)
    if (runif(1) < exp(proposal.log.dens-state.log.dens)) {
      state <- proposal
      state.log.dens <- proposal.log.dens
    }
    X[obs,] <- state
  }
  return(list(X=X, evals=evals))
}
attr(metropolis.sample, 'name') <- 'Metropolis'


###################################################
### chunk number 4: 
###################################################

beta23.log.dens <- function(x) ifelse(x<0 | x>1, -Inf, log(x) + 2*log(1-x))
beta23.dist <- make.dist(ndim=1, name='Beta(2,3)',
                         log.density=beta23.log.dens, mean=2/(2+3))


###################################################
### chunk number 5: 
###################################################
sim <- metropolis.sample(beta23.dist, x0=0.5, sample.size=100, tuning=1)
summary(sim$X)


###################################################
### chunk number 6: 
###################################################
sim.results <- compare.samplers(sample.size=100,
                                dists=list(beta23.dist),
                                samplers=list(metropolis.sample),
                                tuning=c(0.1,1))


